/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail;


/**
 * <p>A structure for holding url and the page title of node.</p>
 * <p>Changes that occurred to this class:
 * Eliminated the parentURL from this class (variable, constructor arg and getter/setter).
 * Updated all documentation.
 * Eliminated all setter methods (making this class immutable).
 * Updated constructor to throw IllegalArgumentException if url string is null.
 * Eliminated synchronization.
 * </p>
 * <p>Thread Safety: This class is immutable and thread safe.</p>
 *
 * @author mishagam, Khristopher
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 * @since 1.0
 */
public class BreadCrumbNode {
    /**
     * <p>Represents the title associated with this node.  This variable is set by the constructor
     *  and is immutable.  This value of this can be null if
     * the title should default to the title found in the PathDiscovery.  This value should not
     *  be null if it's a node that is part of a path returned by the
     * PathDiscovery implementation.  This variable is referenced by the associated getter</p>
     */
    private final String title;

    /**
     * <p>Represents the url (including query string) associated with this node.  This variable
     *  is set by the constructor, is immutable and will never
     * be null.  This variable is referenced by the associated getter</p>
     */
    private final String url;

    /**
     * <p>Constructor for BreadCrumbNode from the specified variables</p>
     * <p><b>Implementation notes: </b> Simply copies the args to the like named variables.  If
     * title is an empty (trim'd) string, null should be used instead</p>
     *
     *
     *
     * @param url A non-null, non-empty (trim'd) url of page represented by this node
     * @param title A possibly null, possibly empty (trim'd) title of page represented by this node
     * @throws IllegalArgumentException if url is null or an empty (trim'd) string
     */
    public BreadCrumbNode(String url, String title) {
        if (url == null) {
            throw new IllegalArgumentException("url cannot be null.");
        }

        if (url.trim().length() == 0) {
            throw new IllegalArgumentException("url cannot be empty string.");
        }

        this.url = url;
        this.title = title;
    }

    /**
     * <p>Simply the getter method for the title of the node.</p>
     *
     *
     * @return A possibly null, non-empty (trim'd) string representing the title of the node
     */
    public String getTitle() {
        return title;
    }

    /**
     * <p>Simply the getter method for the Url.  The returned string will be the URL with any
     *  query string</p>
     *
     *
     * @return A non-null, non-empty (trim'd) string representing the url (including query string) of the node
     */
    public String getUrl() {
        return url;
    }
}
