/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail;

import javax.servlet.jsp.PageContext;


/**
 * <p>
 * This interface defines the contract for classes wishing to discover the path from current
 *  node to the root node.  Implementations of this
 * interface will be called with the current page (specified by the current node) and the
 *  current page context.  The implementation is then
 * suppose to discover the complete path from the current node to the root or return null
 *  when it can't discover the current path.
 * </p>
 * <p>Thread Safety: Implementations should be thread safe in the context of the JSP
 *  rendering process</p>
 *
 *
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public interface PathDiscovery {
    /**
     * <p>This method should return the path from the current node for the given page context.
     *   The current node can have a null title
     * if the current node should default to that found in the data source for this
     *  implmenetation.  The returned nodes, however, should have a
     * title assigned to each node.  The current node's url can include query strings
     *  on both the current node that is called and in the nodes
     * that are returned in the path.  Implementors of this method should return an
     *  array where the 0th index position is the 'root' node and the
     * nth-1 index position is the current node or return null if the current path
     *  could not be found</p>
     *
     *
     * @return An array of BreadCrumbNodes representing the path from root (0th index) to
     *  current node (nth-1 index) or null if path couldn't be found
     * @param currentNode A non-null node representing the current page
     * @param pageContext The non-null page context
     * @throws IllegalArgumentException if either arg is null
     * @throws BreadCrumbException if an exception occurs discovering the page
     */
    public BreadCrumbNode[] getPath(BreadCrumbNode currentNode, PageContext pageContext) throws BreadCrumbException;
}
