/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.nodeformatter;

import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;
import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbTrailTag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;


/**
 * <p>This tag will format the node and title using the html anchor pattern of
 * &quot;&lt;a href='node.getURL()'&gt;title&lt;/a&gt;.</p>
 * <p>Thread Safety: This class is thread safe in the context of the JSP rendering process</p>
 *
 *
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public class HtmlAnchorNodeFormatterTag extends TagSupport {
    /**
     * <p>Constructs the HtmlAnchorNodeFormatterTag using no constructor parameters.</p>
     */
    public HtmlAnchorNodeFormatterTag() {
        super();
    }

    /**
     * <p>This method will format the current node and style as a simple html anchor and then
     * write the results out.</p>
     *
     *
     * @return Always SKIP_BODY
     * @throws JspException if any exception occurs
     */
    public int doStartTag() throws JspException {
        try {
            // get node , style
            BreadCrumbNode node = (BreadCrumbNode)
                (pageContext.getAttribute(BreadCrumbTrailTag.BREADCRUMB_FORMAT_NODE));
            Object style = pageContext.getAttribute(BreadCrumbTrailTag.BREADCRUMB_FORMAT_STYLE_CLASS);

            StringBuffer buffer = new StringBuffer();
            buffer.append("<a");

            // render style
            if (style != null) {
                buffer.append(" class=\"" + style.toString() + "\"");
            }

            // render reference link
            buffer.append(" href=\"");
            buffer.append(node.getUrl());
            buffer.append("\">");

            // render title
            if (node.getTitle() == null) {
                buffer.append("Unspecified");
            } else {
                buffer.append(node.getTitle());
            }

            buffer.append("</a>");

            pageContext.getOut().print(buffer.toString());
        } catch (Exception e) {
            throw new JspException("Failed to render JSP.", e);
        }

        return SKIP_BODY;
    }
}
